@@ -178,9 +178,8 @@ def create_datasources(bus):
                           "clean up stale datasources in DB.")
             sys.exit(1)
         except Exception:
-            LOG.exception("datasource %s creation failed.", ds.name)
-            raise
-
+            LOG.exception("datasource %s creation failed. %s service may not "
+                          "be running.", ds.name, ds.driver)
     return services
 
 
