@@ -389,3 +389,11 @@ class TestNeutronV2Driver(manager_congress.ScenarioPolicyBase):
                                           duration=200, sleep_for=10):
             raise exceptions.TimeoutException("Data did not converge in time "
                                               "or failure in server")
+
+    @test.attr(type='smoke')
+    def test_update_no_error(self):
+        if not test_utils.call_until_true(
+                func=lambda: self.check_datasource_no_error('neutronv2'),
+                duration=30, sleep_for=5):
+            raise exceptions.TimeoutException('Datasource could not poll '
+                                              'without error.')
